#' Trial sequences for practice participants.
#'
#' A dataset containing a small sample of participants
#' in a memory experiment.
#'
#' @format A data frame with 2074 rows and many variables:
#' \describe{
#'   \item{Anon.Student.Id}{unique identifier for each student}
#'   \item{Duration..sec.}{unique identifier for each student}
#'   \item{KC..Default.}{unique identifier for each student}
#'   \item{Outcome}{unique identifier for each student}
#'   ...
#' }
#' @source <https://datashop.memphis.edu/index.jsp>
"samplelkt"

#' Trial sequences for practice participants.
#'
#' A dataset containing a raw sample from the Memphis Datashop.
#'
#' @format A data frame please see the DataShop for more info.
#' \describe{
#' It has many columns.
#' }
#' @source <https://datashop.memphis.edu/Export?datasetId=1465>
"largerawsample"
